@@ -35,6 +35,7 @@ from .type_defs import (
     AvailSuppressionTypeDef,
     BumperTypeDef,
     CdnConfigurationTypeDef,
+    ConfigureLogsForChannelResponseTypeDef,
     ConfigureLogsForPlaybackConfigurationResponseTypeDef,
     CreateChannelResponseTypeDef,
     CreateLiveSourceResponseTypeDef,
@@ -134,6 +135,16 @@ class MediaTailorClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#close)
         """
 
+    def configure_logs_for_channel(
+        self, *, ChannelName: str, LogTypes: Sequence[Literal["AS_RUN"]]
+    ) -> ConfigureLogsForChannelResponseTypeDef:
+        """
+        Configures Amazon CloudWatch log settings for a channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/mediatailor.html#MediaTailor.Client.configure_logs_for_channel)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client/#configure_logs_for_channel)
+        """
+
     def configure_logs_for_playback_configuration(
         self, *, PercentEnabled: int, PlaybackConfigurationName: str
     ) -> ConfigureLogsForPlaybackConfigurationResponseTypeDef:
