@@ -48,8 +48,10 @@ __all__ = (
     "AvailSuppressionTypeDef",
     "BumperTypeDef",
     "CdnConfigurationTypeDef",
-    "ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef",
+    "LogConfigurationForChannelTypeDef",
+    "ConfigureLogsForChannelRequestRequestTypeDef",
     "ResponseMetadataTypeDef",
+    "ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef",
     "HttpPackageConfigurationTypeDef",
     "PrefetchRetrievalTypeDef",
     "DefaultSegmentDeliveryConfigurationTypeDef",
@@ -99,6 +101,7 @@ __all__ = (
     "AccessConfigurationTypeDef",
     "ManifestProcessingRulesTypeDef",
     "PrefetchConsumptionTypeDef",
+    "ConfigureLogsForChannelResponseTypeDef",
     "ConfigureLogsForPlaybackConfigurationResponseTypeDef",
     "EmptyResponseMetadataTypeDef",
     "GetChannelPolicyResponseTypeDef",
@@ -246,11 +249,19 @@ CdnConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef = TypedDict(
-    "ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef",
+LogConfigurationForChannelTypeDef = TypedDict(
+    "LogConfigurationForChannelTypeDef",
     {
-        "PercentEnabled": int,
-        "PlaybackConfigurationName": str,
+        "LogTypes": List[Literal["AS_RUN"]],
+    },
+    total=False,
+)
+
+ConfigureLogsForChannelRequestRequestTypeDef = TypedDict(
+    "ConfigureLogsForChannelRequestRequestTypeDef",
+    {
+        "ChannelName": str,
+        "LogTypes": Sequence[Literal["AS_RUN"]],
     },
 )
 
@@ -265,6 +276,14 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef = TypedDict(
+    "ConfigureLogsForPlaybackConfigurationRequestRequestTypeDef",
+    {
+        "PercentEnabled": int,
+        "PlaybackConfigurationName": str,
+    },
+)
+
 HttpPackageConfigurationTypeDef = TypedDict(
     "HttpPackageConfigurationTypeDef",
     {
@@ -785,6 +804,15 @@ class PrefetchConsumptionTypeDef(
     pass
 
 
+ConfigureLogsForChannelResponseTypeDef = TypedDict(
+    "ConfigureLogsForChannelResponseTypeDef",
+    {
+        "ChannelName": str,
+        "LogTypes": List[Literal["AS_RUN"]],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ConfigureLogsForPlaybackConfigurationResponseTypeDef = TypedDict(
     "ConfigureLogsForPlaybackConfigurationResponseTypeDef",
     {
@@ -1629,6 +1657,7 @@ _RequiredChannelTypeDef = TypedDict(
         "Arn": str,
         "ChannelName": str,
         "ChannelState": str,
+        "LogConfiguration": LogConfigurationForChannelTypeDef,
         "Outputs": List[ResponseOutputItemTypeDef],
         "PlaybackMode": str,
         "Tier": str,
@@ -1676,6 +1705,7 @@ DescribeChannelResponseTypeDef = TypedDict(
         "CreationTime": datetime,
         "FillerSlate": SlateSourceTypeDef,
         "LastModifiedTime": datetime,
+        "LogConfiguration": LogConfigurationForChannelTypeDef,
         "Outputs": List[ResponseOutputItemTypeDef],
         "PlaybackMode": str,
         "Tags": Dict[str, str],
